@@ -1,7 +1,7 @@
 package Sah::Schema::cryptocurrency::code;
 
-our $DATE = '2019-10-24'; # DATE
-our $VERSION = '0.012'; # VERSION
+our $DATE = '2019-11-29'; # DATE
+our $VERSION = '0.013'; # VERSION
 
 our $schema = [str => {
     summary => 'Cryptocurrency code',
@@ -14,7 +14,7 @@ Code will be converted to uppercase.
 
 _
     'x.completion' => 'cryptocurrency_code',
-    'x.perl.coerce_rules' => ['str_toupper'],
+    'x.perl.coerce_rules' => ['From_str::to_upper'],
 }, {}];
 
 1;
@@ -32,7 +32,7 @@ Sah::Schema::cryptocurrency::code - Cryptocurrency code
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::cryptocurrency::code (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2019-10-24.
+This document describes version 0.013 of Sah::Schema::cryptocurrency::code (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2019-11-29.
 
 =head1 DESCRIPTION
 
