@@ -1,7 +1,7 @@
 package Sah::Schema::cryptocurrency::safename;
 
-our $DATE = '2019-10-24'; # DATE
-our $VERSION = '0.012'; # VERSION
+our $DATE = '2019-11-29'; # DATE
+our $VERSION = '0.013'; # VERSION
 
 our $schema = [str => {
     summary => 'Cryptocurrency safename',
@@ -14,7 +14,7 @@ Name will be converted to lowercase.
 
 _
     'x.completion' => 'cryptocurrency_safename',
-    'x.perl.coerce_rules' => ['str_tolower'],
+    'x.perl.coerce_rules' => ['From_str::to_lower'],
 }, {}];
 
 1;
@@ -32,7 +32,7 @@ Sah::Schema::cryptocurrency::safename - Cryptocurrency safename
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::cryptocurrency::safename (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2019-10-24.
+This document describes version 0.013 of Sah::Schema::cryptocurrency::safename (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2019-11-29.
 
 =head1 DESCRIPTION
 
